bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 29. Aventiure
___________________________________________________
| ### <Do> schieden sich di zwene recken lobelich ### Hagen von Tronege vnt ovch her Dieterich ### do blichte veber ahsel der Gvntheres man ### nach einem hergesellen den er vil schiere gewan ### Do sah er Voelker bi Giselhere sten ### den spæhen videlære bat er mit im gen ### wand er vil wol erchand sinen grimmen mvt ### er was an allen dingen ein ritter chven vnd gvt
###### 1757 | ### Noch liezen si di herren vf dem hove sten ### niwan si zwene aleine sach man dannen gan ### veber den hof vil verre fver einen palas wit ### di vz erwelten degene vorhten niemens nit
| ### Si gesazen vor dem hvse gegen sinem sal ### der was Criemhilde vf eine banch ce tal ### do lvhte in von ir libe ir herlich gewant ### genvge da si sazen si heten gerne bechant
###### 1759 | ### Alsam tier div wilden wrden gekapffet an ### di vebermevten helde von den Hivnen man ### si ersah ovch dvrch ein fenster daz Eceln wip ### des wart aber betrvebet der schonen Criemhilden lip
###### 1760 | ### Ez mante si ir leide weinen si began ### des hete michel wnder di Eceln man ### waz ir so schiere betrvebet het den mvt ### si sprach daz hat Hagene ir helde chvne vnde gvt
| ### Si sprachen zv der vrowen wi ist daz geschehen ### wand wir ivch niwliche haben vro gesehen ### nie niemen wart so chvene <derz> iv hat getan ### heizet irz vns rechen ez sol im an sin leben gan
###### 1762 | ### Daz wold ich immer dienen swer rêche miniv leit ### alles des er gerte des wær ich im bereit ### ich bivte mich iv ce fvzen sprach des chveneges wip ### rechet mich an Hanege daz er vliese den lip
###### 1763 | ### Do garten sich vil balde sehzech chvner man ### dvrh Crimhilde wil [379a] len si wolden hine gan ### vnd wolden slahen Hagenen den vil chvenen man ### vnd ovch den videlære daz wart mit rate getan
| ### Do div chveneginne ir shar so chleine sach ### in einem grimmem mvte si zv den helden sprach ### des ir da habt gedingen des svlt ir abe gan ### iane dvrffet ir so ringe nimmer Hagenen bestan
###### 1765 | ### Swi starch vnt swi chvene von Tronege Hagen si ### noch ist er verre stærcher der im da sizet bi ### Volker der videlær der ist ein vebel man ### iane svlt ir di helde niht so lihte bestan
###### 1766 | ### Do si daz gehorten do gart sich ir mer ### vier hvndert sneller recken div kveneginne her ### was des genoete daz si in tæte leit ### da von wart sit degenen vil michel sorge bereit
| ### Do si vil wol gevafent daz ir gesinde sach ### zv den snellen recken div kveneginne sprach ### nv bitet eine wile ia svlt ir stille stan ### ich wil vnder crone zv minen vianden gan
###### 1768 | ### Vnde hoeret itwizze waz mir hat getan ### Hagen von Tronege der Gventheres man ### ich weiz in so vebermveten daz er mir lovgent niht ### so ist ovch mir vnmære swaz im dar vmbe geshihit
###### 1769 | ### Do sach der videlære ein chvene spilman ### di edeln chveneginne ab einer stiege gan ### nider von einem hvse als er daz gesach ### Voker der vil chvene zv sinem hergesellen sprach
| ### Nv schowet vrivnt Hagene wa si dort her gat ### div vns ane triwe inz lant geladet hat ### ine gesach mit kvenges wibe nie so manegen man ### di swert enhend <trvegen> vnd also stritechlichen gan
###### 1771 | ### Wizet ir frivnt Hagene ob si iv sin gehaz ### so wil ich raten ir hvetet deste baz ### des libes vnt der eren ia dvnchet ez mich gvt ### als ich mich versinne si sint zornech gemvt
###### 1772 | ### Vnd sint ovch svemeliche cen brvsten also wit ### swer sin selbes hvete der tv daz enzit ### ich wæn si di liehten brvenne nv dar vnder tragen ### wen si da mit meinen [379b] daz en chan ich niemen gesagen
| ### Do sprach in zornes mvote Hagen der chvene man ### ich weiz wol daz iz allez ist vf mich getan ### daz si div liehten waffen tragent an der hant ### vor den moeht ich noch geriten in der Bvrgonden lant
###### 1774 | ### Nv sagt mir vrivnt Volker ob ir mir welt gestan ### ob wellent mit mir striten di Criemhilde man ### daz lazet ir mich hoeren als lieb als ich iv si ### ich won iv immer mere mit triwen dienstlichen bi
###### 1775 | ### Ich hilf iv sicherlichen sprach der spilman ### ob ich uns engegene sæhe den kvnech selbe gan ### mit allen sinen recken di wile ich leben mvz ### so entwich ich <iv> dvrch vorhte nimmer einen fvz
| ### Nv lon iv got von himele vil edel Volker ### ob si mit mir striten wes bedarf ich danne mer ### sit ir mir helffen wellet als ich han vernomen ### so svln dise recken wil gewærlichen chomen
###### 1777 | ### Nv ste wir von dem sedele sprach der spilman ### si ist ein chveneginne vnd lat si fvr gan ### bietet ir di ere si ist ein edel wip ### da mit ist ovch getivret vnser ieweders lip
###### 1778 | ### Nein dvrch mine liebe sprach aber Hagene ### so wolden sich versinnen dise degene ### daz ichz dvrch vorhte tæte vnd sold ich hin gen ### ich en wil dvrch ir deheinen nimmer von dem sedele sten
| ### Ia zimet ez vns beiden zeware lazzen daz ### zwiv sold ich den eren der mir ist gehaz ### daz engetvn ich nimmer di wile ich han den lip ### ovch enrvch ich waz mich genidet des kvnech Ecelen wip
###### 1780 | ### Der vebermvete Hagene leit veber siniv bein ### ein vil liehtez waffen vz des knopffe shein ### ein vil liehter iaspes grvener danne ein gras ### wol erchand ez Criemhilt daz ez Sifrides was
| ### Do si daz swert erchande do gi ir trvrens not ### sin gehelze daz was gvldin div scheide ein porte rot ### ez mante si ir leide weinen si began ### ich wæne ez hete dar vmbe der chvene Hagen getan
###### 1782 | ### Volker der snelle zoch naher vf der banch ### einen videlbogen starchen vil michel vnd lanch ### gelich einem swerte [380a] vil sharpf vnde breit ### do sazen <vnder vorhte> di zwene degene gemeit
###### 1783 | ### Nv dvhten sich so here di zwene chvene man ### daz si niht wolden von dem sædel stan ### dvrch niemens vorhte des gie in an den fvz ### div edele chveneginne vnd bot in vientlichen grvz
| ### Si sprach her Hagene wer hat nach iv gesant ### daz ir getorstet riten her in diz lant ### vnde ir daz wol erchandet waz ir mir habet getan ### hetet ir gvote sinne ir soldet ez pilliche lan
###### 1785 | ### Nach mir sande niemen sprach do Hagene ### man ladete her ce lande drie degene ### di heizent mine herren vnd bin ich ir man ### in deheiner hovereise bin ich selten hinder in bestan
###### 1786 | ### Si sprach nv sagt mir mere zwiv tatet ir daz ### daz ir daz habt verdienet daz ich iv bin gehaz ### ir slvoget Sifriden den minen lieben man ### des ich vnz an min ende immer genvch ce weinen han
| ### Er sprach waz soldes mere der rede ist nv genvch ### ich pinz aber Hagene der Sifriden slvch ### den helt ce sinen handen wi sere er des engalt ### daz div schoene Criemhilt di <vrovn> Prvnnhilden shalt
###### 1788 | ### Ez ist et ane lovgen chvneginne rich ### ich han es alles shvlde des schaden shedelich ### nv rechez swer der welle ez si wip oder man ### ichen wolde danne liegen ich han iv leides vil getan
###### 1789 | ### Si sprach nv hoert ir rechen wa er mir lovgent niht ### aller miner leide swaz im da von gesiht ### daz ist mir vil vnmære ir Eceln man ### di vebermveten degene ein ander sahen si an
| ### Swer den strit da hvebe so wære daz geschehen ### daz man den zwein gesellen der eren mvese iehen ### wan siz in stvrmen heten vil diche wol getan ### des sich iene vermazen dvrch vorhte mvsen si daz lan
###### 1791 | ### Do sprach ein der rechen wes seht ir mich an ### daz ich ê da lobte des wil abe gan ### da ich dvrch niemens gabe verliesen wil den lip ### ia wil vns verleiten des kvnech Eceln wip
###### 1792 | ### Do sprach da bi ein ander des selben han ich mvt ### der mir gæbe tverne von rotem golde gvt ### disen videlære wold ich niht bestan ### dvrch sine swinden bliche di ich an im gesehen han
| ### Ovch erchenne ich Hagenen von sinen [380b] ivngen tagen ### des mach man von dem rechen lihte mir gesagen ### in zwein vnd zweinzech stvrmen han ich in gesehen ### da vil maniger vrowen ist herceleit geschehen
###### 1794 | ### Er vnt der von Spanye taten manegen stich ### do si hi bi Eceln vahten manech wich ### ce eren dem chvenege des ist vil geschehen ### dar vmb mvz man Hagenen der eren pilliche iehen
###### 1795 | ### Dannoch was der reche siner iar ein chint ### daz do di tvmben waren wi grise di nv sint ### nv ist er chomen ce witzen vnd ist ein grimmech man ### ovch treit er Palmvngen daz er vil vebele gewan
| ### Da mit was gescheiden daz niemen dane streit ### do wart der chveneginne hercenlichen leit ### di helde cherten dannen ia vorhten si den tot ### von dem videlære des gie in sicherlichen not
###### 1797 | ### Do sprach der videlære wir haben daz wol ersehen ### daz wir hi vinde vinden als wir ê horten iehen ### wir svln zv den chvenegen hin ce hove gan ### sone tar vnser herren mit strite niemen bestan
###### 1798 | ### Wi dicke ein man dvrch vorhte manigiv dinch verlat ### swa so frivnt bi frivnde frivntlichen stat ### vnd hat er gvote sinne daz ers nine tvt ### schade vil maniges wirt von sinnen wol behvt
| ### Nv wil ich iv volgen sprach do Hagene ### si giengen da si fvnden di zieren degene ### in grozem antpfange an dem hove stan ### Volker der vil chvene vil lvte sprechen began
###### 1800 | ### zv den sinen herren wi lange welt ir sten ### daz ir ivch lazet <dringen> ir svlt ce hove gen ### vnde horet an dem kvenege wi er si gemvt ### do sach man sich gesellen di helde chvene vnd gvt
###### 1801 | ### Der fvrste von Berne nam an di hant ### Gvntheren den vil richen von Bvrgonden lant ### Irnfrit der nam Gernoten den vil chvnen man ### do sach man Rvdgeren ce hove mit Giselheren gan
| ### Swi iemen sich gesellete vnd ovh [381a] ce hove gie ### Volker vnde Hagen di geschieden sich nie ### niwan in einem stvrme an ir endes zit ### daz mvsen edel vrowen beweinen groezlichen sit
###### 1803 | ### Do sach man <mit> den kvenegen hin ce hove gan ### ir edeln ingesindes tvsent chvener man ### darveber sehzech rechen di waren mit in chomen ### di het in sinem lande der chvene Hagen genomen
###### 1804 | ### Hawart vnd ovch Irinch di zwene vzerwelten man ### di sach man <gesellichen> bi den chvenegen gan ### Danchwart vnd Wolfhart ein tiwerlicher degen ### di sach man wol ir tvgende vor den anderen pflegen
| ### Do der vogt von Rine in den palas gie ### Ecel der vil riche daz langer niht enlie ### er spranch von sinem sedele als er in <chomen> sach ### er grvz so rehte schoene von den chvnegen im geschach
###### 1806 | ### Sit willechomen her Gvnther vnd ovch her Gernot ### vnd iwer brvder Giselher min dienest ich iv enbot ### mit triwen vlizechlichen ce Wormez veber Rin ### vnd allez daz gesinde sol mir willechomen sin
###### 1807 | ### Nv sit vns goze willechomen ir zwene degene ### Volker der vil chvene vnd ovch Hagene ### mir vnd miner vrowen her in dizze lant ### si hat iv boten manige hince Rine gesant
| ### Do sprach von Tronege Hagene des han ich vil vernomen ### wære ich dvrch mine herren cen Hivnen her niht chomen ### so wære ich iv cen eren geritten in daz lant ### do nam der wirt vil edele di lieben geste bi der hant
###### 1809 | ### Er brahte si cem sedele da er selbe saz ### do schancte man den gesten mit vlize tet man daz ### in witen goldes schallen <met> moraz vnde win ### vnde bat di ellenden groze willechomen sin
###### 1810 | ### Do sprach der kvnech Ecel des wil ich iv veriehen ### mir enchvnde in dirre werlde lieber niht geschehen ### denne ovch an iv helden daz ir mir sit bechomen ### des ist der chveneginne vil michel trvren benomen [381b]
| ### Mich nimt des michel wnder waz ich iv habe getan ### so manigen gast vil edel den ich gewnnen han ### daz ir nie gervchtet chomen in miniv lant ### daz ich ivh nv gesehen han daz ist cen vrevden mir gewant
###### 1812 | ### Des antwrte Rvedeger ein ritter hohgemvt ### ir mvgt si sehen gerne ir triwe div ist gvt ### der minnen vrowen mage vo schone chvnnen pflegen ### si bringent iv ce hvse vil manegen wætlichen degen
###### 1813 | ### An svnewenden abent di herren waren chomen ### in Eceln hof des richen vil selten ist vernomen ### von also hohem grvze als er di helde enpfie ### nv was ovch ezens zit der Rvedger mit in ce tisshe gie
| ### Ein wirt bi sinen gesten schoner nie gesaz ### man gab in vollechlichen trinchen vnde maz ### alles des si gerten des was man in bereit ### man hete von den helden vil michel wnder geseit

<<< Übersicht <<< vorige Seite nächste Seite >>>